Privkey

Struct Privkey 

pub struct Privkey(/* private fields */);
WireGuard private key.

Implementations

Source

impl Privkey

pub fn new(data: [u8; 32]) -> Self

Create new from existing data. Warning: this function does not check if the passed data is valid.

Source

impl Privkey

pub fn from_hex(data: &str) -> Result<Self, ParseError>

Parse key from hex.

pub fn to_hex(&self) -> String

Encode key as hex.

Source

impl Privkey

pub fn from_base64(data: &str) -> Result<Self, ParseError>

Parse key from base64.

pub fn from_base64_urlsafe(data: &str) -> Result<Self, ParseError>

Parse key from base64 with urlsafe encoding.

pub fn to_base64(&self) -> String

Encode key as base64.

pub fn to_base64_urlsafe(&self) -> String

Encode key as base64 with urlsafe encoding.

Source

impl Privkey

pub fn parse(data: &str) -> Result<Self, ParseError>

Try parsing from string.

Source

impl Privkey

pub fn generate() -> Self

Generate new private key using the kernel randomness generator.

pub fn valid(&self) -> bool

Attempt to check if this private key is valid.

pub fn pubkey(&self) -> Pubkey

Generate the corresponding public key for this private key.